@@ -2,16 +2,22 @@ order = [
     'tpQtLib.core.color',
     'tpQtLib.core.consts',
     'tpQtLib.core.qtutils',
+    'tpQtLib.core.formatters',
     'tpQtLib.core.base',
+    'tpQtLib.core.cache',
     'tpQtLib.core.animation',
     'tpQtLib.core.settings',
     'tpQtLib.core.style',
+    'tpQtLib.core.pixmap',
+    'tpQtLib.core.icon',
     'tpQtLib.core.theme',
+    'tpQtLib.core.mixin',
+    'tpQtLib.core.resource',
     'tpQtLib.core.statusbar',
     'tpQtLib.core.tooltips',
     'tpQtLib.core.buttons',
     'tpQtLib.core.dragger',
-    'tpQtLib.core.theme',
+    'tpQtLib.core.resizers',
     'tpQtLib.core.dialog',
     'tpQtLib.core.window'
 ]
