@@ -51,7 +51,7 @@ if QT_AVAILABLE:
             PYSIDEUIC_AVAILABLE = False
         from PySide2.QtCore import QMetaObject
         from PySide2.QtUiTools import QUiLoader
-    else:
+    elif __binding__ == 'PySide':
         try:
             import shiboken
         except ImportError:
@@ -75,6 +75,9 @@ if QT_AVAILABLE:
                 from tpDcc.libs.qt.externals.pysideutils.QtUiTools import QUiLoader
             except ImportError:
                 UILOADER_AVAILABLE = False
+    else:
+        UILOADER_AVAILABLE = False
+        PYSIDEUIC_AVAILABLE = False
 
 import tpDcc
 from tpDcc.libs import qt
@@ -1656,11 +1659,12 @@ def iterate_parents(widget):
         yield parent
 
 
-def iterate_children(widget, skip=None):
+def iterate_children(widget, skip=None, qobj_class=None):
     """
     Yields all descendant widgets depth first of the given widget
     :param widget: QWWidget, widget to iterate through
     :param skip: str, if the widget has this property, children will be skip
+    :param qobj_class:
     :return:
     """
 
@@ -1668,5 +1672,74 @@ def iterate_children(widget, skip=None):
         yield child
         if skip is not None and child.property(skip) is not None:
             continue
+        if qobj_class is not None and not isinstance(child, qobj_class):
+            continue
         for grand_cihld in iterate_children(widget=child, skip=skip):
             yield grand_cihld
+
+
+def is_stackable(widget):
+    """
+    Returns whether or not given widget is stackable
+    :param widget: QWidget
+    :return: bool
+    """
+
+    return issubclass(widget, QWidget) and hasattr(widget, 'widget') and hasattr(widget, 'currentChanged')
+
+
+def get_screen_color(global_pos):
+    """
+    Grabs the screen color of the given global position in the current active screen
+    :param global_pos: QPoint
+    :return: QColor
+    """
+
+    screen_num = QApplication.desktop().screenNumber(global_pos)
+    screen = QApplication.screens()[screen_num]
+    wid = QApplication.desktop().winId()
+    img = screen.grabWindow(wid, global_pos.x(), global_pos.y(), 1, 1).toImage()
+
+    return QColor(img.pixel(0, 0))
+
+
+def set_vertical_size_policy(widget, policy):
+    """
+    Sets the vertical policy of the given widget
+    :param widget: QtWidgets.QWidget
+    :param policy: QtWidgets.QSizePolicy, new polity to apply to vertical policy
+    """
+
+    size_policy = widget.sizePolicy()
+    size_policy.setVerticalPolicy(policy)
+    widget.setSizePolicy(size_policy)
+
+
+def set_horizontal_size_policy(widget, policy):
+    """
+    Sets the horizontal policy of the given widget
+    :param widget: QtWidgets.QWidget
+    :param policy: QtWidgets.QSizePolicy, new polity to apply to horizontal policy
+    """
+
+    size_policy = widget.sizePolicy()
+    size_policy.setHorizontalPolicy(policy)
+    widget.setSizePolicy(size_policy)
+
+
+def set_size_hint(widget, size):
+    """
+    Sets the size hint of the given widget (using a monkey-patch approach)
+    :param widget: QtWidgets.QWidget
+    :param size: QtCore.QSize
+    """
+
+    widget.sizeHint = lambda: size
+
+
+def process_ui_events():
+    """
+    Processes all events currently in the application events queue
+    """
+
+    QApplication.processEvents()
