@@ -19,9 +19,9 @@ import appdirs
 
 from tpDcc.libs import qt
 import tpDcc as tp
-from tpDcc import register
 from tpDcc.libs.python import path, folder
-from tpDcc.libs.qt.core import qtutils, base, animation, color, theme, statusbar, dragger, settings as qt_settings
+from tpDcc.libs.qt.core import mixin, qtutils, animation, theme, statusbar, dragger, resizers, settings as qt_settings
+from tpDcc.libs.qt.widgets import layouts
 
 
 class WindowContents(QFrame, object):
@@ -34,6 +34,7 @@ class WindowContents(QFrame, object):
         super(WindowContents, self).__init__(parent=parent)
 
 
+@mixin.theme_mixin
 class BaseWindow(QMainWindow, object):
 
     closed = Signal()
@@ -50,6 +51,7 @@ class BaseWindow(QMainWindow, object):
         self._theme = None
         self._docks = list()
         self._toolbars = dict()
+        self._menubar = None
         self._dpi = kwargs.get('dpi', 1.0)
         self._fixed_size = kwargs.get('fixed_size', False)
         self._init_width = kwargs.get('width', 600)
@@ -67,6 +69,8 @@ class BaseWindow(QMainWindow, object):
         prefs_settings = kwargs.pop('preferences_settings', None)
         auto_load = kwargs.get('auto_load', True)
 
+        super(BaseWindow, self).__init__(parent)
+
         if not hasattr(self, 'WindowId'):
             if window_id:
                 self.WindowId = window_id
@@ -74,8 +78,6 @@ class BaseWindow(QMainWindow, object):
                 self._force_disable_saving = True
                 self.WindowId = str(uuid.uuid4())
 
-        super(BaseWindow, self).__init__(parent)
-
         self.setObjectName(str(self.WindowId))
         self.setWindowTitle(kwargs.get('title', self.WindowName))
         self.setWindowIcon(kwargs.get('icon', tp.ResourcesMgr().icon('tpdcc')))
@@ -83,6 +85,10 @@ class BaseWindow(QMainWindow, object):
         self.resize(self._init_width, self._init_height)
         self.center(self._init_width, self._init_height)
 
+        # Load base generic window UI
+        self._base_ui()
+
+        # Load custom window UI
         self.ui()
         self.setup_signals()
 
@@ -90,6 +96,8 @@ class BaseWindow(QMainWindow, object):
 
         if auto_load:
             self.load_theme()
+        else:
+            self.reload_stylesheet()
 
     # ============================================================================================================
     # OVERRIDES
@@ -113,9 +121,11 @@ class BaseWindow(QMainWindow, object):
 
     def closeEvent(self, event):
         self.save_settings()
+        self.closed.emit()
+        for child in self.findChildren(QWidget):
+            child.close()
         self.setParent(None)
         self.deleteLater()
-        self.closed.emit()
 
     def addDockWidget(self, area, dock_widget, orientation=Qt.Horizontal, tabify=True):
         """
@@ -150,7 +160,7 @@ class BaseWindow(QMainWindow, object):
         Forces Qt application to update GUI between calculations
         """
 
-        QApplication.processEvents()
+        qtutils.process_ui_events()
 
     def center(self, width=None, height=None):
         """
@@ -208,7 +218,7 @@ class BaseWindow(QMainWindow, object):
         :param msecs: int
         """
 
-        self._status_bar.show_ok_message(message=message, msecs=msecs)
+        self._self._status_bar.show_ok_message(message=message, msecs=msecs)
 
     def show_info_message(self, message, msecs=None):
         """
@@ -248,8 +258,8 @@ class BaseWindow(QMainWindow, object):
         """
 
         main_layout = QVBoxLayout()
-        main_layout.setContentsMargins(0, 0, 0, 0)
-        main_layout.setSpacing(0)
+        main_layout.setContentsMargins(2, 2, 2, 2)
+        main_layout.setSpacing(2)
 
         return main_layout
 
@@ -258,6 +268,13 @@ class BaseWindow(QMainWindow, object):
         Function used to define UI of the window
         """
 
+        pass
+
+    def _base_ui(self):
+        """
+        Internal function that setup basic window UI
+        """
+
         self.setDockNestingEnabled(True)
         self.setDocumentMode(True)
         self.setDockOptions(QMainWindow.AllowNestedDocks | QMainWindow.AnimatedDocks | QMainWindow.AllowTabbedDocks)
@@ -267,11 +284,12 @@ class BaseWindow(QMainWindow, object):
 
         central_widget = QWidget(parent=self)
         self.setCentralWidget(central_widget)
-        self._central_layout = base.VerticalLayout(margins=(0, 0, 0, 0), spacing=0)
+        self._central_layout = layouts.VerticalLayout(margins=(0, 0, 0, 0), spacing=0)
         central_widget.setLayout(self._central_layout)
 
         self._top_widget = QWidget()
-        self._top_layout = base.VerticalLayout(margins=(0, 0, 0, 0), spacing=0)
+        self._top_widget.setObjectName('topWindowWidget')
+        self._top_layout = layouts.VerticalLayout(margins=(0, 0, 0, 0), spacing=0)
         self._top_widget.setLayout(self._top_layout)
 
         # Status Bar
@@ -283,7 +301,7 @@ class BaseWindow(QMainWindow, object):
         # self.statusBar().setVisible(self._show_status_bar)
 
         # MenuBar
-        self._menubar = QMenuBar()
+        self._menubar = QMenuBar(self)
         if self._init_menubar:
             self._has_main_menu = True
             self._file_menu = self.menuBar().addMenu('File')
@@ -299,29 +317,12 @@ class BaseWindow(QMainWindow, object):
                 self._view_menu.addAction(i.toggleViewAction())
         self._top_layout.addWidget(self._menubar)
 
-        self._base_window = QMainWindow()
-        self._base_window.setParent(central_widget)
-        self._base_window.setAttribute(Qt.WA_AlwaysShowToolTips, True)
-        self._base_window.setWindowFlags(Qt.Widget)
-        self._base_window.setAttribute(Qt.WA_TranslucentBackground)
-        # if qtutils.is_pyside2():
-        #     self._base_window.setWindowFlags(
-        #         self.windowFlags() | Qt.Widget | Qt.FramelessWindowHint | Qt.NoDropShadowWindowHint)
-        # else:
-        #     self._base_window.setWindowFlags(Qt.Widget | Qt.FramelessWindowHint | Qt.NoDropShadowWindowHint)
-        self._base_window.setDockOptions(
-            QMainWindow.AnimatedDocks | QMainWindow.AllowNestedDocks | QMainWindow.AllowTabbedDocks)
-        window_layout = QVBoxLayout()
-        window_layout.setContentsMargins(0, 0, 0, 0)
-        window_layout.setSpacing(0)
-        self._base_window.setLayout(window_layout)
         self.main_widget = WindowContents()
         self.main_layout = self.get_main_layout()
         self.main_widget.setLayout(self.main_layout)
-        self._base_window.setCentralWidget(self.main_widget)
 
         self._central_layout.addWidget(self._top_widget)
-        self._central_layout.addWidget(self._base_window)
+        self._central_layout.addWidget(self.main_widget)
 
     # ============================================================================================================
     # SIGNALS
@@ -403,14 +404,7 @@ class BaseWindow(QMainWindow, object):
         :return: dict
         """
 
-        # "accentColor": "rgb(0, 175, 240, 255)",
-
-        return {
-            "theme": {
-                "accentColor": "rgb(80, 80, 80, 255)",
-                "backgroundColor": "rgb(45, 45, 45, 255)",
-            }
-        }
+        return {}
 
     def set_settings(self, settings):
         """
@@ -539,18 +533,20 @@ class BaseWindow(QMainWindow, object):
         """
 
         def_settings = self.default_settings()
-        def_theme_settings = def_settings.get('theme')
-        accent_color = self.settings().getw('theme/accentColor') or def_theme_settings['accentColor']
-        background_color = self.settings().getw('theme/backgroundColor') or def_theme_settings['backgroundColor']
+        def_theme_settings = def_settings.get('theme', dict())
+        accent_color = self.settings().getw('theme/accent_color') or def_theme_settings.get('accent_color')
+        background_color = self.settings().getw('theme/background_color') or def_theme_settings.get('background_color')
         accent_color = 'rgb(%d, %d, %d, %d)' % accent_color.getRgb() if isinstance(
             accent_color, QColor) else accent_color
         background_color = 'rgb(%d, %d, %d, %d)' % background_color.getRgb() if isinstance(
             background_color, QColor) else background_color
 
-        theme_settings = {
-            "accentColor": accent_color,
-            "backgroundColor": background_color
-        }
+        theme_settings = dict()
+        if accent_color:
+            theme_settings['accent_color'] = accent_color
+        if background_color:
+            theme_settings['background_color'] = background_color
+
         self.set_theme_settings(theme_settings)
 
     def theme(self):
@@ -560,7 +556,7 @@ class BaseWindow(QMainWindow, object):
         """
 
         if not self._theme:
-            self._theme = theme.Theme()
+            return None
 
         return self._theme
 
@@ -583,7 +579,7 @@ class BaseWindow(QMainWindow, object):
         current_theme = self._settings.get('theme', 'default')
         new_theme = tp.ResourcesMgr().theme(current_theme)
         if not new_theme:
-            new_theme = theme.Them()
+            new_theme = theme.Theme()
         new_theme.set_settings(settings)
         self.set_theme(new_theme)
 
@@ -594,39 +590,15 @@ class BaseWindow(QMainWindow, object):
 
         current_theme = self.theme()
         current_theme.set_dpi(self.dpi())
-        options = current_theme.options()
         stylesheet = current_theme.stylesheet()
-
-        all_widgets = self.main_layout.findChildren(QObject)
-
-        text_color = color.Color.from_string(options["ITEM_TEXT_COLOR"])
-        text_selected_color = color.Color.from_string(options["ITEM_TEXT_SELECTED_COLOR"])
-        background_color = color.Color.from_string(options["ITEM_BACKGROUND_COLOR"])
-        background_hover_color = color.Color.from_string(options["ITEM_BACKGROUND_HOVER_COLOR"])
-        background_selected_color = color.Color.from_string(options["ITEM_BACKGROUND_SELECTED_COLOR"])
-
         self.setStyleSheet(stylesheet)
 
-        for w in all_widgets:
-            found = False
-            if hasattr(w, 'set_text_color'):
-                w.set_text_color(text_color)
-                found = True
-            if hasattr(w, 'set_text_selected_color'):
-                w.set_text_selected_color(text_selected_color)
-                found = True
-            if hasattr(w, 'set_background_color'):
-                w.set_background_color(background_color)
-                found = True
-            if hasattr(w, 'set_background_hover_color'):
-                w.set_background_hover_color(background_hover_color)
-                found = True
-            if hasattr(w, 'set_background_selected_color'):
-                w.set_background_selected_color(background_selected_color)
-                found = True
-
-            if found:
-                w.update()
+        # # TODO: This operation is VERY heavy. Find a better way of doing this
+        # all_widgets = qtutils.iterate_children(self.main_widget, qobj_class=QObject)
+        # for w in all_widgets:
+        #     if hasattr(w, 'setStyleSheet'):
+        #         w.setStyleSheet(stylesheet)
+        #         w.update()
 
     # ============================================================================================================
     # TOOLBAR
@@ -639,7 +611,8 @@ class BaseWindow(QMainWindow, object):
         """
 
         new_toolbar = QToolBar(name)
-        self._base_window.addToolBar(area, new_toolbar)
+        self.addToolBar(area, new_toolbar)
+
         return new_toolbar
 
     # ============================================================================================================
@@ -752,9 +725,7 @@ class MainWindow(BaseWindow, object):
         self._preference_widgets_classes = list()
         self._toolset = kwargs.get('toolset', None)
         self._transparent = kwargs.get('transparent', False)
-        self._frameless = kwargs.get('frameless', True)
         self._config = kwargs.pop('config', None)
-        self._dockable = getattr(self, 'WindowDockable', False)
         self._was_docked = False
         self._window_loaded = False
         self._window_closed = False
@@ -762,18 +733,21 @@ class MainWindow(BaseWindow, object):
 
         super(MainWindow, self).__init__(parent=parent, **kwargs)
 
-        self.set_frameless(self._frameless)
-        if not self._frameless:
-            self.set_resizer_active(False)
+        self._dockable = getattr(self, 'WindowDockable', False)
+        frameless = kwargs.get('frameless', True)
+        self.set_frameless(frameless)
+        if not frameless:
+            self.set_resizers_active(False)
             self._dragger.set_dragging_enabled(False)
             self._dragger.set_window_buttons_state(False)
         else:
             self._dragger.set_dragging_enabled(True)
             self._dragger.set_window_buttons_state(True)
+        self._dragger._toggle_frameless.setChecked(self.is_frameless())
 
         # We set the window title after UI is created
-        self.setWindowTitle(kwargs.get('title', 'tete'))
-        self.setWindowIcon(kwargs.get('icon', tp.ResourcesMgr().icon('ok')))
+        self.setWindowTitle(kwargs.get('title', 'tpDcc'))
+        self.setWindowIcon(kwargs.get('icon', tp.ResourcesMgr().icon('tpdcc')))
 
         MainWindow._WINDOW_INSTANCES[self.WindowId] = {
             'window': self
@@ -793,24 +767,6 @@ class MainWindow(BaseWindow, object):
 
         return self._widget
 
-    @property
-    def frameless(self):
-        """
-        Returns whether this window can be frameless or not
-        :return: bool
-        """
-
-        return self._frameless
-
-    @frameless.setter
-    def frameless(self, flag):
-        """
-        Sets whether or not this window can be frameless
-        :param flag: bool
-        """
-
-        self._frameless = flag
-
     # ============================================================================================================
     # CLASS METHODS
     # ============================================================================================================
@@ -907,12 +863,13 @@ class MainWindow(BaseWindow, object):
             r.windowResizedFinished.connect(self.windowResizedFinished)
         self.set_resize_directions()
 
-        grid_layout = base.GridLayout()
+        grid_layout = layouts.GridLayout()
         grid_layout.setHorizontalSpacing(0)
         grid_layout.setVerticalSpacing(0)
+        grid_layout.setSpacing(0)
         grid_layout.setContentsMargins(0, 0, 0, 0)
         grid_layout.addWidget(self._top_widget, 1, 1, 1, 1)
-        grid_layout.addWidget(self._base_window, 2, 1, 1, 1)
+        grid_layout.addWidget(self.main_widget, 2, 1, 1, 1)
         grid_layout.addWidget(self._top_left_resizer, 0, 0, 1, 1)
         grid_layout.addWidget(self._top_resizer, 0, 1, 1, 1)
         grid_layout.addWidget(self._top_right_resizer, 0, 2, 1, 1)
@@ -921,16 +878,20 @@ class MainWindow(BaseWindow, object):
         grid_layout.addWidget(self._bottom_left_resizer, 3, 0, 1, 1)
         grid_layout.addWidget(self._bottom_resizer, 3, 1, 1, 1)
         grid_layout.addWidget(self._bottom_right_resizer, 3, 2, 1, 1)
-        # grid_layout.setColumnStretch(1, 1)
-        # grid_layout.setRowStretch(2, 1)
+        grid_layout.setColumnStretch(1, 1)
+        grid_layout.setRowStretch(2, 1)
 
         self._central_layout.addLayout(grid_layout)
 
-        shadow_effect = QGraphicsDropShadowEffect(self)
-        shadow_effect.setBlurRadius(qtutils.dpi_scale(15))
-        shadow_effect.setColor(QColor(0, 0, 0, 150))
-        shadow_effect.setOffset(qtutils.dpi_scale(0))
-        self.setGraphicsEffect(shadow_effect)
+        # Shadow effect for window
+        # BUG: This causes some rendering problems when using other shadow effects in child widgets of the window
+        # BUG: Also detected problems when updating wigets (tree views, web browsers, etc)
+        # https://bugreports.qt.io/browse/QTBUG-35196
+        # shadow_effect = QGraphicsDropShadowEffect(self)
+        # shadow_effect.setBlurRadius(qtutils.dpi_scale(15))
+        # shadow_effect.setColor(QColor(0, 0, 0, 150))
+        # shadow_effect.setOffset(qtutils.dpi_scale(0))
+        # self.setGraphicsEffect(shadow_effect)
 
         for r in self._resizers:
             r.windowResizedFinished.connect(self.windowResizedFinished)
@@ -971,6 +932,21 @@ class MainWindow(BaseWindow, object):
     # BASE
     # ============================================================================================================
 
+    def tick(self, delta_seconds, *args, **kwargs):
+        """
+        Function that is called taking into account DCC delta seconds
+        NOTE: This function MUST be override if necessary in each DCC, by default it does nothing
+        :param delta_seconds: float
+        :param args:
+        :param kwargs:
+        :return:
+        """
+
+        # TODO: We can use QTimers to setup a tick and use QApplication event loop
+        # TODO: I do not want to force the creation of a QTimer, so for now we implement this for each DCC
+
+        pass
+
     def exists(self):
         """
         Returns whether or not this window exists
@@ -1019,14 +995,14 @@ class MainWindow(BaseWindow, object):
             else:
                 window.setWindowFlags(Qt.Window | Qt.FramelessWindowHint)
                 window.setWindowFlags(window.windowFlags() ^ Qt.WindowMinMaxButtonsHint)
-            self.set_resizer_active(True)
+            self.set_resizers_active(True)
         elif not flag and self.is_frameless():
             window.setAttribute(Qt.WA_TranslucentBackground)
             if qtutils.is_pyside2() or qtutils.is_pyqt5():
                 window.setWindowFlags(window.windowFlags() | Qt.FramelessWindowHint | Qt.NoDropShadowWindowHint)
             else:
                 self.setWindowFlags(Qt.Window | Qt.FramelessWindowHint)
-            self.set_resizer_active(False)
+            self.set_resizers_active(False)
 
         window.show()
 
@@ -1034,7 +1010,7 @@ class MainWindow(BaseWindow, object):
     # RESIZERS
     # ============================================================================================================
 
-    def set_resizer_active(self, flag):
+    def set_resizers_active(self, flag):
         """
         Sets whether resizers are enable or not
         :param flag: bool
@@ -1047,19 +1023,37 @@ class MainWindow(BaseWindow, object):
             for r in self._resizers:
                 r.hide()
 
+    def set_resizers_enabled(self, flag, resizers_to_edit=resizers.Resizers.All):
+        """
+        Enabled or disable window resizers
+        :param flag: bool
+        :param resizers_to_edit:
+        """
+
+        resizers_to_enable = list()
+        if resizers_to_edit & resizers.Resizers.Corners == resizers.Resizers.Corners:
+            resizers_to_enable += self.get_corner_resizers()
+        if resizers_to_edit & resizers.Resizers.Vertical == resizers.Resizers.Vertical:
+            resizers_to_enable += self.get_vertical_resizers()
+        if resizers_to_edit & resizers.Resizers.Horizontal == resizers.Resizers.Horizontal:
+            resizers_to_enable += self.get_horizontal_resizers()
+
+        [resizer.setEnabled(flag) for resizer in resizers_to_enable]
+
     def set_resize_directions(self):
         """
         Sets the resize directions for the resizer widget of this window
         """
 
-        self._top_resizer.set_resize_direction(ResizeDirection.Top)
-        self._bottom_resizer.set_resize_direction(ResizeDirection.Bottom)
-        self._right_resizer.set_resize_direction(ResizeDirection.Right)
-        self._left_resizer.set_resize_direction(ResizeDirection.Left)
-        self._top_left_resizer.set_resize_direction(ResizeDirection.Left | ResizeDirection.Top)
-        self._top_right_resizer.set_resize_direction(ResizeDirection.Right | ResizeDirection.Top)
-        self._bottom_left_resizer.set_resize_direction(ResizeDirection.Left | ResizeDirection.Bottom)
-        self._bottom_right_resizer.set_resize_direction(ResizeDirection.Right | ResizeDirection.Bottom)
+        self._top_resizer.set_resize_direction(resizers.ResizeDirection.Top)
+        self._bottom_resizer.set_resize_direction(resizers.ResizeDirection.Bottom)
+        self._right_resizer.set_resize_direction(resizers.ResizeDirection.Right)
+        self._left_resizer.set_resize_direction(resizers.ResizeDirection.Left)
+        self._top_left_resizer.set_resize_direction(resizers.ResizeDirection.Left | resizers.ResizeDirection.Top)
+        self._top_right_resizer.set_resize_direction(resizers.ResizeDirection.Right | resizers.ResizeDirection.Top)
+        self._bottom_left_resizer.set_resize_direction(resizers.ResizeDirection.Left | resizers.ResizeDirection.Bottom)
+        self._bottom_right_resizer.set_resize_direction(
+            resizers.ResizeDirection.Right | resizers.ResizeDirection.Bottom)
 
     def get_resizers_height(self):
         """
@@ -1089,19 +1083,43 @@ class MainWindow(BaseWindow, object):
 
         return total_width
 
+    def get_horizontal_resizers(self):
+        """
+        Returns all horizontal resizers
+        :return: list
+        """
+
+        return [self._left_resizer, self._right_resizer]
+
+    def get_vertical_resizers(self):
+        """
+        Returns all vertical resizers
+        :return: list
+        """
+
+        return [self._top_resizer, self._bottom_resizer]
+
+    def get_corner_resizers(self):
+        """
+        Returns all corner resizers
+        :return: list
+        """
+
+        return [self._top_left_resizer, self._top_right_resizer, self._bottom_left_resizer, self._bottom_right_resizer]
+
     def _setup_resizers(self):
         """
         Internal function that setup window resizers
         """
 
-        self._top_resizer = VerticalResizer()
-        self._bottom_resizer = VerticalResizer()
-        self._right_resizer = HorizontalResizer()
-        self._left_resizer = HorizontalResizer()
-        self._top_left_resizer = CornerResizer()
-        self._top_right_resizer = CornerResizer()
-        self._bottom_left_resizer = CornerResizer()
-        self._bottom_right_resizer = CornerResizer()
+        self._top_resizer = resizers.VerticalResizer()
+        self._bottom_resizer = resizers.VerticalResizer()
+        self._right_resizer = resizers.HorizontalResizer()
+        self._left_resizer = resizers.HorizontalResizer()
+        self._top_left_resizer = resizers.CornerResizer()
+        self._top_right_resizer = resizers.CornerResizer()
+        self._bottom_left_resizer = resizers.CornerResizer()
+        self._bottom_right_resizer = resizers.CornerResizer()
 
         self._resizers = [
             self._top_resizer, self._top_right_resizer, self._right_resizer, self._bottom_right_resizer,
@@ -1622,225 +1640,6 @@ class DirectoryWindow(MainWindow, object):
             folder.create_folder(name=None, directory=directory)
 
 
-class ResizeDirection:
-    Left = 1
-    Top = 2
-    Right = 4
-    Bottom = 8
-
-
-class WindowResizer(QFrame, object):
-    windowResized = Signal()
-    windowResizedStarted = Signal()
-    windowResizedFinished = Signal()
-
-    def __init__(self, parent):
-        super(WindowResizer, self).__init__(parent)
-
-        self._init()
-
-        self._direction = 0
-        self._widget_mouse_pos = None
-        self._widget_geometry = None
-        self._frameless = None
-
-        self.setStyleSheet('background: transparent;')
-
-        self.windowResizedStarted.connect(self._on_window_resize_started)
-
-    def paintEvent(self, event):
-        """
-        Overrides base QFrame paintEvent function
-        Override to make mouse events work in transparent widgets
-        :param event: QPaintEvent
-        """
-
-        painter = QPainter(self)
-        painter.fillRect(self.rect(), QColor(255, 0, 0, 1))
-        painter.end()
-
-    def leaveEvent(self, event):
-        """
-        Overrides base QFrame leaveEvent function
-        :param event: QEvent
-        """
-
-        QApplication.restoreOverrideCursor()
-
-    def mousePressEvent(self, event):
-        """
-        Overrides base QFrame mousePressEvent function
-        :param event: QEvent
-        """
-
-        self.windowResizedStarted.emit()
-
-    def mouseMoveEvent(self, event):
-        """
-        Overrides base QFrame mouseMoveEvent function
-        :param event: QEvent
-        """
-
-        self.windowResized.emit()
-
-    def mouseReleaseEvent(self, event):
-        """
-        Overrides base QFrame mouseReleaseEvent function
-        :param event: QEvent
-        """
-
-        self.windowResizedFinished.emit()
-
-    def setParent(self, parent):
-        """
-        Overrides base QFrame setParent function
-        :param event: QWidget
-        """
-
-        self._frameless = parent
-        super(WindowResizer, self).setParent(parent)
-
-    def set_resize_direction(self, direction):
-        """
-        Sets the resize direction
-
-        .. code-block:: python
-
-            setResizeDirection(ResizeDirection.Left | ResizeDireciton.Top)
-
-        :param direction: ResizeDirection
-        :return: ResizeDirection
-        :rtype: int
-        """
-        self._direction = direction
-
-    def _init(self):
-        """
-        Internal function that initializes reisizer
-        Override in custom resizers
-        """
-
-        self.windowResized.connect(self._on_window_resized)
-
-    def _on_window_resized(self):
-        """
-        Internal function that resizes the frame based on the mouse position and the current direction
-        """
-
-        pos = QCursor.pos()
-        new_geo = self.window().frameGeometry()
-
-        min_width = self.window().minimumSize().width()
-        min_height = self.window().minimumSize().height()
-
-        if self._direction & ResizeDirection.Left == ResizeDirection.Left:
-            left = new_geo.left()
-            new_geo.setLeft(pos.x() - self._widget_mouse_pos.x())
-            if new_geo.width() <= min_width:
-                new_geo.setLeft(left)
-        if self._direction & ResizeDirection.Top == ResizeDirection.Top:
-            top = new_geo.top()
-            new_geo.setTop(pos.y() - self._widget_mouse_pos.y())
-            if new_geo.height() <= min_height:
-                new_geo.setTop(top)
-        if self._direction & ResizeDirection.Right == ResizeDirection.Right:
-            new_geo.setRight(pos.x() + (self.minimumSize().width() - self._widget_mouse_pos.x()))
-        if self._direction & ResizeDirection.Bottom == ResizeDirection.Bottom:
-            new_geo.setBottom(pos.y() + (self.minimumSize().height() - self._widget_mouse_pos.y()))
-
-        x = new_geo.x()
-        y = new_geo.y()
-        w = max(new_geo.width(), min_width)
-        h = max(new_geo.height(), min_height)
-
-        self.window().setGeometry(x, y, w, h)
-
-    def _on_window_resize_started(self):
-        self._widget_mouse_pos = self.mapFromGlobal(QCursor.pos())
-        self._widget_geometry = self.window().frameGeometry()
-
-
-class CornerResizer(WindowResizer, object):
-    """
-    Resizer for window corners
-    """
-
-    def __init__(self, parent=None):
-        super(CornerResizer, self).__init__(parent)
-
-    def enterEvent(self, event):
-        """
-        Overrides base QFrame enterEvenet function
-        :param event: QEvent
-        """
-
-        if self._direction == ResizeDirection.Left | ResizeDirection.Top or \
-                self._direction == ResizeDirection.Right | ResizeDirection.Bottom:
-            QApplication.setOverrideCursor(Qt.SizeFDiagCursor)
-        elif self._direction == ResizeDirection.Right | ResizeDirection.Top or \
-                self._direction == ResizeDirection.Left | ResizeDirection.Bottom:
-            QApplication.setOverrideCursor(Qt.SizeBDiagCursor)
-
-    def _init(self):
-        """
-        Overrides base WindowResizer _int function
-        """
-
-        super(CornerResizer, self)._init()
-
-        self.setFixedSize(qtutils.size_by_dpi(QSize(10, 10)))
-
-
-class VerticalResizer(WindowResizer, object):
-    """
-    Resize for top and bottom sides of the window
-    """
-
-    def __init__(self, parent=None):
-        super(VerticalResizer, self).__init__(parent)
-
-    def enterEvent(self, event):
-        """
-        Overrides base QFrame enterEvenet function
-        :param event: QEvent
-        """
-
-        QApplication.setOverrideCursor(Qt.SizeVerCursor)
-
-    def _init(self):
-        """
-        Overrides base WindowResizer _int function
-        """
-
-        super(VerticalResizer, self)._init()
-        self.setFixedHeight(qtutils.dpi_scale(8))
-
-
-class HorizontalResizer(WindowResizer, object):
-    """
-    Resize for left and right sides of the window
-    """
-
-    def __init__(self, parent=None):
-        super(HorizontalResizer, self).__init__(parent)
-
-    def enterEvent(self, event):
-        """
-        Overrides base QFrame enterEvenet function
-        :param event: QEvent
-        """
-
-        QApplication.setOverrideCursor(Qt.SizeHorCursor)
-
-    def _init(self):
-        """
-        Overrides base WindowResizer _int function
-        """
-
-        super(HorizontalResizer, self)._init()
-        self.setFixedWidth(qtutils.dpi_scale(8))
-
-
 class DockWidget(QDockWidget, object):
     """
     Base docked widget
@@ -1866,6 +1665,3 @@ class DockWindowContainer(DockWidget, object):
         if self.widget():
             self.widget().close()
         super(DockWindowContainer, self).closeEvent(event)
-
-
-register.register_class('Window', MainWindow)
