@@ -12,7 +12,6 @@ import math
 import shutil
 import tempfile
 import traceback
-
 from datetime import datetime
 from functools import partial
 
@@ -50,7 +49,6 @@ class LibraryItem(QTreeWidgetItem, object):
     DataRole = consts.ITEM_DEFAULT_DATA_ROLE
 
     ThreadPool = QThreadPool()
-    DefaultThumbnailPath = tp.ResourcesMgr().get('icons', 'thumbnail.png')
 
     MAX_ICON_SIZE = consts.ITEM_DEFAULT_MAX_ICON_SIZE
     DEFAULT_FONT_SIZE = consts.ITEM_DEFAULT_FONT_SIZE
@@ -71,11 +69,12 @@ class LibraryItem(QTreeWidgetItem, object):
 
     MenuName = consts.ITEM_DEFAULT_MENU_NAME
     MenuOrder = consts.ITEM_DEFAULT_MENU_ORDER
-    MenuIconPath = consts.ITEM_DEFAULT_MENU_ICON_PATH
+    MenuIconName = consts.ITEM_DEFAULT_MENU_ICON
 
     RegisterOrder = 10
-    TypeIconPath = ''
+    TypeIconName = ''
     DisplayInSidebar = False
+    DefaultThumbnailName = 'thumbnail.png'
     CreateWidgetClass = savewidget.SaveWidget
     PreviewWidgetClass = loadwidget.LoadWidget
 
@@ -132,6 +131,9 @@ class LibraryItem(QTreeWidgetItem, object):
         self._modal = None
         self._library = None
         self._library_window = None
+        self._type_icon_path = tp.ResourcesMgr().get('icons', self.TypeIconName)
+        self._menu_icon_path = tp.ResourcesMgr().get('icons', self.MenuIconName)
+        self._default_thumbnail_path = tp.ResourcesMgr().get('icons', self.DefaultThumbnailName)
 
         super(LibraryItem, self).__init__(*args)
 
@@ -178,7 +180,7 @@ class LibraryItem(QTreeWidgetItem, object):
         """
 
         if cls.MenuName:
-            action_icon = QIcon(cls.MenuIconPath)
+            action_icon = tp.ResourcesMgr().icon(cls.MenuIconName)
             callback = partial(cls.show_create_widget, library_window)
             action = QAction(action_icon, cls.MenuName, menu)
             action.triggered.connect(callback)
@@ -784,7 +786,10 @@ class LibraryItem(QTreeWidgetItem, object):
         """
 
         if self.path():
-            return self.path()
+            file_path = path_utils.clean_path(os.path.join(self.path(), self.name()))
+            if not os.path.isfile(file_path):
+                file_path = self.path()
+            return file_path
 
         return self._mime_text or self.text(0)
 
@@ -792,6 +797,7 @@ class LibraryItem(QTreeWidgetItem, object):
         """
         Sets the mime text for drag and drop
         :param text: str
+
         """
 
         self._mime_text = text
@@ -803,7 +809,10 @@ class LibraryItem(QTreeWidgetItem, object):
         """
 
         if self.path():
-            return QUrl('file:///{}'.format(self.path()))
+            file_path = path_utils.clean_path(os.path.join(self.path(), self.name()))
+            if not os.path.isfile(file_path):
+                file_path = self.path()
+            return QUrl('file:///{}'.format(file_path))
 
         if not self._url:
             self._url = QUrl(self.text(0))
@@ -1040,7 +1049,7 @@ class LibraryItem(QTreeWidgetItem, object):
         :return: str
         """
 
-        return self.TypeIconPath
+        return self._type_icon_path
 
     def thumbnail_path(self):
         """
@@ -1049,7 +1058,7 @@ class LibraryItem(QTreeWidgetItem, object):
         """
 
         if not self.path():
-            return self.DefaultThumbnailPath
+            return self._default_thumbnail_path
 
         thumbnail_path = self.path() + '/thumbnail.jpg'
         if os.path.exists(thumbnail_path):
@@ -1059,7 +1068,7 @@ class LibraryItem(QTreeWidgetItem, object):
         if os.path.exists(thumbnail_path):
             return thumbnail_path
 
-        return self.DefaultThumbnailPath
+        return self._default_thumbnail_path
 
     """
     ##########################################################################################
@@ -1097,9 +1106,11 @@ class LibraryItem(QTreeWidgetItem, object):
         :param kwargs:
         :return:
         """
+
         path = path or self.path()
         if path and not path.endswith(self.Extension):
-            path += self.Extension
+            extension = self.Extension if self.Extension.startswith('.') else '.{}'.format(self.Extension)
+            path += extension
 
         self.set_path(path)
 
@@ -1109,7 +1120,7 @@ class LibraryItem(QTreeWidgetItem, object):
         if os.path.exists(path):
             self.show_already_existing_dialog()
 
-        temp_path = os.path.join(tempfile.mkdtemp(), self.name())
+        temp_path = tempfile.mkdtemp()
         if not os.path.isdir(temp_path):
             os.mkdir(temp_path)
         valid_save = self.write(temp_path, *args, **kwargs)
@@ -1117,21 +1128,31 @@ class LibraryItem(QTreeWidgetItem, object):
             qt.logger.warning('Item {} not saved!'.format(path))
             if self.library_window():
                 self.library_window().show_warning_message('Item {} not saved!'.format(path))
-            return
+            if os.path.isdir(temp_path):
+                folder_utils.delete_folder(temp_path)
+            return False
 
         new_path = os.path.join(os.path.dirname(path), self.name())
-        shutil.move(temp_path, new_path)
+        if not os.path.isdir(new_path):
+            shutil.move(temp_path, new_path)
+        else:
+            folder_utils.move_folder(temp_path, new_path, only_contents=True)
+            folder_utils.delete_folder(temp_path)
+
         self.set_path(new_path)
         self.save_item_data()
-        if self.library_window():
-            self.library_window().select_items([self])
 
         comment = kwargs.get('comment', None)
         self.save_version(new_path, comment)
 
+        if self.library_window():
+            self.library_window().select_items([self])
+
         self.saved.emit(self)
         qt.logger.debug('Item Saved: {}'.format(self.path()))
 
+        return True
+
     def save_version(self, path, comment):
         """
         Function that creates a new version of the item data
@@ -1512,7 +1533,7 @@ class LibraryItem(QTreeWidgetItem, object):
         Returns the default thumbnail path
         :return: str
         """
-        return self.DefaultThumbnailPath
+        return self._default_thumbnail_path
 
     def default_thumbnail_icon(self):
         """
@@ -2262,9 +2283,14 @@ class LibraryFolderItem(LibraryItem, object):
 
     MenuName = 'Folder'
     MenuOrder = 1
-    MenuIconPath = tp.ResourcesMgr().get('icons', 'color', 'folder.png')
-    DefaultThumbnailPath = tp.ResourcesMgr().get('icons', 'folder.png')
-    TrashIconPath = tp.ResourcesMgr().get('icons', 'trash.png')
+    MenuIconName = 'folder.png'
+    DefaultThumbnailName = 'folder.png'
+    TrashIconName = 'trash.png'
+
+    def __init__(self, path='', library=None, library_window=None, *args):
+        self._trash_icon_path = tp.ResourcesMgr().get('icons', self.TrashIconName)
+
+        super(LibraryFolderItem, self).__init__(path=path, library=library, library_window=library_window, *args)
 
     @classmethod
     def match(cls, path):
@@ -2371,7 +2397,7 @@ class LibraryFolderItem(LibraryItem, object):
 
         data = super(LibraryFolderItem, self).item_data()
         if data.get('path').endswith('Trash'):
-            data['iconPath'] = self.TrashIconPath
+            data['iconPath'] = self._trash_icon_path
 
         return data
 
@@ -2418,18 +2444,51 @@ class BaseItem(LibraryItem, object):
         self.transfer_object().load(objects=objects, namespaces=namespaces, **kwargs)
         qt.logger.debug('Loaded: {}'.format(self.transfer_path()))
 
-    def write(self, path, objects, icon_path='', **options):
+        return True
+
+    def save(self, path=None, *args, **kwargs):
+        """
+        Saves current item
+        :param path:
+        :param args:
+        :param kwargs:
+        :return:
+        """
+
+        valid_save = super(BaseItem, self).save(path=path, *args, **kwargs)
+        if not valid_save:
+            transfer_path = self.transfer_path()
+            if os.path.isfile(transfer_path):
+                folder_utils.delete_folder(os.path.dirname(transfer_path))
+            return False
+
+        return True
+
+    def write(self, path, objects, icon_path='', sequence_path='', **options):
         """
         Writes all the given object data to the given path on disk
+        This function just setup the basic setup prior or doing the write, overrides
+        this function in custom items to implement the write functionality
         :param path: str
         :param objects: list(str)
         :param icon_path: str
+        :param sequence_path: str
         :param options: dict
         """
 
+        # if icon_path:
+        #     base_name = os.path.basename(icon_path)
+        #     shutil.copy(icon_path, path + '/' + base_name)
+
         if icon_path:
-            base_name = os.path.basename(icon_path)
-            shutil.copy(icon_path, path + '/' + base_name)
+            shutil.copyfile(icon_path, path + '/thumbnail.jpg')
+        if sequence_path:
+            shutil.move(sequence_path, path + '/sequence')
+
+        objects = objects or list()
+        self.transfer_object().add(objects)
+
+        return True
 
     def load_validator(self, **options):
         """
@@ -2657,7 +2716,8 @@ class BaseItem(LibraryItem, object):
 
         if not self._transfer_object:
             path = self.transfer_path()
-            self._transfer_object = self.transfer_class().from_path(path)
+            force_creation = bool(os.path.isfile(path))
+            self._transfer_object = self.transfer_class().from_path(path, force_creation=force_creation)
 
         return self._transfer_object
 
@@ -2667,9 +2727,11 @@ class BaseItem(LibraryItem, object):
         :return: str or None
         """
 
-        return self.transfer_object().metadata().get('user', 'Unknown')
+        transfer_object = self.transfer_object()
+        if not transfer_object:
+            return 'Unknown'
 
-        # return self.transfer_object().metadata().get('user', '')
+        return transfer_object.metadata().get('user', 'Unknown')
 
     def description(self):
         """
@@ -2677,7 +2739,11 @@ class BaseItem(LibraryItem, object):
         :return: str
         """
 
-        return self.transfer_object().metadata().get('description', '')
+        transfer_object = self.transfer_object()
+        if not transfer_object:
+            return ''
+
+        return transfer_object.metadata().get('description', '')
 
     def object_count(self):
         """
@@ -2685,7 +2751,11 @@ class BaseItem(LibraryItem, object):
         :return: int
         """
 
-        return self.transfer_object().count()
+        transfer_object = self.transfer_object()
+        if not transfer_object:
+            return 0
+
+        return transfer_object.count()
 
     # ============================================================================================================
     # SCENE
