@@ -11,8 +11,8 @@ from Qt.QtCore import *
 from Qt.QtWidgets import *
 
 import tpDcc
-from tpDcc.libs.qt.core import consts, qtutils, base, dpi
-from tpDcc.libs.qt.widgets import buttons, lineedit
+from tpDcc.libs.qt.core import consts, qtutils, base, dpi, mixin
+from tpDcc.libs.qt.widgets import layouts, buttons, lineedit
 
 
 class SlidingStackedWidget(QStackedWidget, object):
@@ -155,6 +155,16 @@ class SlidingStackedWidget(QStackedWidget, object):
         self.animFinished.emit(self._next)
 
 
+@mixin.stacked_opacity_animation_mixin
+class SlidingOpacityStackedWidget(QStackedWidget, object):
+    """
+    Custom stack widget that activates opacity animation when current stack index changes
+    """
+
+    def __init__(self, parent=None):
+        super(SlidingOpacityStackedWidget, self).__init__(parent)
+
+
 class StackItem(QFrame, object):
 
     minimized = Signal()
@@ -212,7 +222,7 @@ class StackItem(QFrame, object):
         # theme = tpDcc.ToolsMgr().get_tool_theme('tpDcc-tools-hub')
         # border_width = qtutils.dpi_scale_divide(theme.STACK_BORDER_WIDTH)
         border_width = qtutils.dpi_scale_divide(1)
-        self.main_layout = base.VerticalLayout(
+        self.main_layout = layouts.VerticalLayout(
             margins=(border_width, border_width, border_width, border_width), spacing=0)
         self.setLayout(self.main_layout)
 
@@ -225,7 +235,7 @@ class StackItem(QFrame, object):
             self._title_frame.item_icon_button.hide()
 
         self._widget_hider = StackHiderWidget(parent=self)
-        self._contents_layout = base.VerticalLayout(spacing=0)
+        self._contents_layout = layouts.VerticalLayout(spacing=0)
         self._contents_layout.setContentsMargins(*self._contents_margins)
         self._contents_layout.setSpacing(self._contents_spacing)
         self._widget_hider.setLayout(self._contents_layout)
@@ -498,12 +508,14 @@ class StackTitleFrame(QFrame, dpi.DPIScaling):
         shift_down_icon = tpDcc.ResourcesMgr().icon('arrow_down')
 
         self.setContentsMargins(*qtutils.margins_dpi_scale(0, 0, 0, 0))
-        self._extras_layout = base.HorizontalLayout(margins=(0, 0, 0, 0), spacing=0)
-        self._horizontal_layout = base.HorizontalLayout(spacing=0)
+        self._extras_layout = layouts.HorizontalLayout(margins=(0, 0, 0, 0), spacing=0)
+        self._horizontal_layout = layouts.HorizontalLayout(spacing=0)
         self.setLayout(self._horizontal_layout)
 
         self._line_edit = lineedit.ClickLineEdit(self._title)
         self._line_edit.setObjectName('lineEdit')
+        self._line_edit.setFocusPolicy(Qt.NoFocus)
+        self._line_edit.setVisible(False)
         self._line_edit.setAttribute(Qt.WA_TransparentForMouseEvents)
         if not self._title_editable:
             self._line_edit.setReadOnly(True)
